@@ -10,9 +10,10 @@ class Addon(Model):
 
     fields = ["id", "name", "invoice_name", "description", "pricing_model", "type", "charge_type", \
     "price", "currency_code", "period", "period_unit", "unit", "status", "archived_at", "enabled_in_portal", \
-    "tax_code", "sku", "accounting_code", "accounting_category1", "accounting_category2", "is_shippable", \
-    "shipping_frequency_period", "shipping_frequency_period_unit", "resource_version", "updated_at", \
-    "invoice_notes", "taxable", "tax_profile_id", "meta_data", "tiers"]
+    "tax_code", "avalara_sale_type", "avalara_transaction_type", "avalara_service_type", "sku", \
+    "accounting_code", "accounting_category1", "accounting_category2", "is_shippable", "shipping_frequency_period", \
+    "shipping_frequency_period_unit", "resource_version", "updated_at", "invoice_notes", "taxable", \
+    "tax_profile_id", "meta_data", "tiers"]
 
 
     @staticmethod
