@@ -8,7 +8,8 @@ class Card(Model):
     fields = ["payment_source_id", "status", "gateway", "gateway_account_id", "first_name", \
     "last_name", "iin", "last4", "card_type", "funding_type", "expiry_month", "expiry_year", "issuing_country", \
     "billing_addr1", "billing_addr2", "billing_city", "billing_state_code", "billing_state", "billing_country", \
-    "billing_zip", "ip_address", "customer_id", "masked_number"]
+    "billing_zip", "created_at", "resource_version", "updated_at", "ip_address", "customer_id", \
+    "masked_number"]
 
 
     @staticmethod
