@@ -5,7 +5,7 @@ from chargebee import APIError
 
 class CreditNote(Model):
     class LineItem(Model):
-      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "amount", "pricing_model", "is_taxed", "tax_amount", "tax_rate", "discount_amount", "item_level_discount_amount", "description", "entity_type", "tax_exempt_reason", "entity_id"]
+      fields = ["id", "subscription_id", "date_from", "date_to", "unit_amount", "quantity", "amount", "pricing_model", "is_taxed", "tax_amount", "tax_rate", "discount_amount", "item_level_discount_amount", "description", "entity_type", "tax_exempt_reason", "entity_id", "customer_id"]
       pass
     class Discount(Model):
       fields = ["amount", "description", "entity_type", "entity_id"]
@@ -20,7 +20,7 @@ class CreditNote(Model):
       fields = ["name", "amount", "description"]
       pass
     class LineItemTax(Model):
-      fields = ["line_item_id", "tax_name", "tax_rate", "tax_amount", "tax_juris_type", "tax_juris_name", "tax_juris_code"]
+      fields = ["line_item_id", "tax_name", "tax_rate", "is_partial_tax_applied", "is_non_compliance_tax", "taxable_amount", "tax_amount", "tax_juris_type", "tax_juris_name", "tax_juris_code"]
       pass
     class LinkedRefund(Model):
       fields = ["txn_id", "applied_amount", "applied_at", "txn_status", "txn_date", "txn_amount"]
@@ -32,8 +32,8 @@ class CreditNote(Model):
     fields = ["id", "customer_id", "subscription_id", "reference_invoice_id", "type", "reason_code", \
     "status", "vat_number", "date", "price_type", "currency_code", "total", "amount_allocated", \
     "amount_refunded", "amount_available", "refunded_at", "voided_at", "resource_version", "updated_at", \
-    "sub_total", "round_off_amount", "line_items", "discounts", "line_item_discounts", "line_item_tiers", \
-    "taxes", "line_item_taxes", "linked_refunds", "allocations", "deleted"]
+    "sub_total", "round_off_amount", "fractional_correction", "line_items", "discounts", "line_item_discounts", \
+    "line_item_tiers", "taxes", "line_item_taxes", "linked_refunds", "allocations", "deleted"]
 
 
     @staticmethod
