@@ -6,7 +6,8 @@ from chargebee import APIError
 class VirtualBankAccount(Model):
 
     fields = ["id", "customer_id", "email", "bank_name", "account_number", "routing_number", \
-    "swift_code", "gateway", "gateway_account_id", "reference_id", "deleted"]
+    "swift_code", "gateway", "gateway_account_id", "resource_version", "updated_at", "created_at", \
+    "reference_id", "deleted"]
 
 
     @staticmethod
@@ -24,3 +25,7 @@ class VirtualBankAccount(Model):
     @staticmethod
     def list(params=None, env=None, headers=None):
         return request.send_list_request('get', request.uri_path("virtual_bank_accounts"), params, env, headers)
+
+    @staticmethod
+    def delete_local(id, env=None, headers=None):
+        return request.send('post', request.uri_path("virtual_bank_accounts",id,"delete_local"), None, env, headers)
